#!/bin/bash

if [ $(which nc-usbaudio) ]; then
	nc_usbaudio=$(which nc-usbaudio)
elif [ -e nc-usbaudio ]; then
	nc_usbaudio=$PWD/nc-usbaudio
else
	echo "Unable to find nc-usbaudio"
	exit 1
fi

## Use environment variable for NC session
# NC_SESSION=1
USB_CLASS=1

if [ -z "$NC_SESSION" ]; then
	echo "Environment variable not set: NC_SESSION."
	exit 1
fi

asoundrc_file=$HOME/.asoundrc.$NC_SESSION

asoundrc=$(cat << EOF

# Playback: dmix plugin
pcm.dmixer__CARD__ {
        type dmix
        ipc_key { @func igetenv
                vars [ NC_DMIX_KEY ]
                default 1234
        }
        ipc_key_add_uid true
        slave {
                pcm "hw:__CARD__,0"
	}
}

# Record: dsnoop plugin
pcm.dsnooper__CARD__ {
        type dsnoop
        ipc_key { @func igetenv
                vars [ NC_DMIX_KEY ]
                default 1234
        }
        ipc_key_add_uid true
        slave {
                pcm "hw:__CARD__,0"
	}
}

# Duplex: asym plugin
pcm.asymer__CARD__ {
	type asym
	playback.pcm "dmixer__CARD__"
	capture.pcm "dsnooper__CARD__"
}
pcm.pasymer__CARD__ {
	type plug
	slave.pcm "asymer__CARD__"
}

# aoss
pcm.dsp__CARD__ {
	type plug
	slave.pcm "asymer__CARD__"
}

EOF
)

asoundrc_default=$(cat << EOF

# Default control device
ctl.!default {
	type hw
	card __CARD__
}

# Default playback device: the asym (duplex) plugin
pcm.!default {
        type plug
        slave.pcm "asymer__CARD__"
}

EOF
)

rm -f $asoundrc_file

sysfspaths=$($nc_usbaudio $NC_SESSION $USB_CLASS)
if (($?!=0)); then
	echo "No ALSA devices assigned to this session"
	exit 1
fi

device_counter=0

for sysfspath in $sysfspaths; do
        device=$(find $sysfspath -regex '.*sound:audio[0-9]*')
        device=${device//*sound:audio/}
        # configure a section for each assigned USB audio device
        if [ -n "$device" ]; then
		((device_counter++))
                echo "$asoundrc" |
                        sed "s/__CARD__/$device/g"  >> "$asoundrc_file"
        # set default device
                echo "$asoundrc_default" |
                        sed "s/__CARD__/$device/g" >> "$asoundrc_file"
		break
        fi
done

if ((device_counter==0)); then
	echo "Unable to find ALSA device"
	exit 1
fi

